@@ -57,14 +57,13 @@
 #include "selinux.h"
 #include "settings-keys.h"
 #include "cgroups.h"
-#include "treeview.h"
+#include "legacy/treeview.h"
 #include "systemd.h"
 
 #ifdef GDK_WINDOWING_X11
 #include <gdk/gdkx.h>
 #endif
 
-ProcInfo::UserMap ProcInfo::users;
 ProcInfo::List ProcInfo::all;
 std::map<pid_t, guint64> ProcInfo::cpu_times;
 
@@ -80,7 +79,7 @@ cb_save_tree_state(gpointer, gpointer data)
 {
     GsmApplication * const app = static_cast<GsmApplication *>(data);
 
-    gsm_tree_view_save_state (GSM_TREE_VIEW (app->tree));
+    gsm_tree_view_save_state (app->tree);
 }
 
 static void
@@ -115,9 +114,7 @@ cb_tree_button_pressed (GtkWidget *widget, GdkEventButton *event, gpointer data)
 
     gtk_tree_path_free (path);
 
-    gtk_menu_popup (GTK_MENU (app->popup_menu),
-                    NULL, NULL, NULL, NULL,
-                    event->button, event->time);
+    gtk_menu_popup_at_pointer (GTK_MENU (app->popup_menu), NULL);
     return TRUE;
 }
 
@@ -126,9 +123,7 @@ cb_tree_popup_menu (GtkWidget *widget, gpointer data)
 {
     GsmApplication *app = (GsmApplication *) data;
 
-    gtk_menu_popup (GTK_MENU (app->popup_menu),
-                    NULL, NULL, NULL, NULL,
-                    0, gtk_get_current_event_time ());
+    gtk_menu_popup_at_pointer (GTK_MENU (app->popup_menu), NULL);
 
     return TRUE;
 }
@@ -255,7 +250,7 @@ process_visibility_func (GtkTreeModel *model, GtkTreeIter *iter, gpointer data)
 
 	// in case we are in dependencies view, we show (and expand) rows not matching the text, but having a matching child
     gboolean match = false;
-    if (g_settings_get_boolean (app->settings, GSM_SETTING_SHOW_DEPENDENCIES)) {
+    if (app->settings->get_boolean (GSM_SETTING_SHOW_DEPENDENCIES)) {
         GtkTreeIter child;
         if (gtk_tree_model_iter_children (model, &child, iter)) {
             gboolean child_match = FALSE;
@@ -297,14 +292,12 @@ proctable_clear_tree (GsmApplication * const app)
 
     update_sensitivity(app);
 }
-                                                        
+
 static void
-cb_show_dependencies_changed (GSettings *settings, const gchar *key, gpointer data)
-{
-    GsmApplication *app = (GsmApplication *) data;
+cb_show_dependencies_changed(Gio::Settings& settings, Glib::ustring key, GsmApplication* app) {
     if (app->timeout) {
         gtk_tree_view_set_show_expanders (GTK_TREE_VIEW (app->tree),
-                                      g_settings_get_boolean (settings, GSM_SETTING_SHOW_DEPENDENCIES));
+                                          settings.get_boolean (GSM_SETTING_SHOW_DEPENDENCIES));
 
         proctable_clear_tree (app);
         proctable_update (app);
@@ -312,19 +305,17 @@ cb_show_dependencies_changed (GSettings *settings, const gchar *key, gpointer da
 }
 
 static void
-cb_show_whose_processes_changed (GSettings *settings, const gchar *key, gpointer data)
-{
-    GsmApplication *app = (GsmApplication *) data;
+cb_show_whose_processes_changed(Gio::Settings& settings, Glib::ustring key, GsmApplication* app) {
     if (app->timeout) {
         proctable_clear_tree (app);
         proctable_update (app);
     }
 }
 
-GtkWidget *
+GsmTreeView *
 proctable_new (GsmApplication * const app)
 {
-    GtkWidget *proctree;
+    GsmTreeView *proctree;
     GtkTreeStore *model;
     GtkTreeModelFilter *model_filter;
     GtkTreeModelSort *model_sort;
@@ -363,7 +354,7 @@ proctable_new (GsmApplication * const app)
     };
 
     gint i;
-    GSettings * settings = g_settings_get_child (app->settings, GSM_SETTINGS_CHILD_PROCESSES);
+    auto settings = g_settings_get_child (app->settings->gobj (), GSM_SETTINGS_CHILD_PROCESSES);
     model = gtk_tree_store_new (NUM_COLUMNS,
                                 G_TYPE_STRING,      /* Process Name */
                                 G_TYPE_STRING,      /* User         */
@@ -403,8 +394,7 @@ proctable_new (GsmApplication * const app)
     gtk_tree_view_set_model (GTK_TREE_VIEW (proctree), GTK_TREE_MODEL (model_sort));
 
     gtk_tree_view_set_tooltip_column (GTK_TREE_VIEW (proctree), COL_TOOLTIP);
-    gtk_tree_view_set_show_expanders (GTK_TREE_VIEW (proctree),
-                                      g_settings_get_boolean (app->settings, GSM_SETTING_SHOW_DEPENDENCIES));
+    gtk_tree_view_set_show_expanders (GTK_TREE_VIEW (proctree), app->settings->get_boolean (GSM_SETTING_SHOW_DEPENDENCIES));
     gtk_tree_view_set_enable_search (GTK_TREE_VIEW (proctree), FALSE);
     g_object_unref (G_OBJECT (model));
 
@@ -429,7 +419,7 @@ proctable_new (GsmApplication * const app)
     gtk_tree_view_column_set_min_width (column, 1);
     gtk_tree_view_column_set_reorderable(column, TRUE);
 
-    gsm_tree_view_append_and_bind_column (GSM_TREE_VIEW (proctree), column);
+    gsm_tree_view_append_and_bind_column (proctree, column);
     gtk_tree_view_set_expander_column (GTK_TREE_VIEW (proctree), column);
 
     for (i = COL_USER; i <= COL_PRIORITY; i++) {
@@ -451,7 +441,7 @@ proctable_new (GsmApplication * const app)
         gtk_tree_view_column_set_resizable(col, TRUE);
         gtk_tree_view_column_set_sort_column_id(col, i);
         gtk_tree_view_column_set_reorderable(col, TRUE);
-        gsm_tree_view_append_and_bind_column (GSM_TREE_VIEW (proctree), col);
+        gsm_tree_view_append_and_bind_column (proctree, col);
 
         // type
         switch (i) {
@@ -565,20 +555,20 @@ proctable_new (GsmApplication * const app)
     app->last_vscroll_value = 0;
 
     if (!cgroups_enabled ())
-        gsm_tree_view_add_excluded_column (GSM_TREE_VIEW (proctree), COL_CGROUP);
+        gsm_tree_view_add_excluded_column (proctree, COL_CGROUP);
 
     if (!procman::systemd_logind_running())
     {
-        gsm_tree_view_add_excluded_column (GSM_TREE_VIEW (proctree), COL_UNIT);
-        gsm_tree_view_add_excluded_column (GSM_TREE_VIEW (proctree), COL_SESSION);
-        gsm_tree_view_add_excluded_column (GSM_TREE_VIEW (proctree), COL_SEAT);
-        gsm_tree_view_add_excluded_column (GSM_TREE_VIEW (proctree), COL_OWNER);
+        gsm_tree_view_add_excluded_column (proctree, COL_UNIT);
+        gsm_tree_view_add_excluded_column (proctree, COL_SESSION);
+        gsm_tree_view_add_excluded_column (proctree, COL_SEAT);
+        gsm_tree_view_add_excluded_column (proctree, COL_OWNER);
     }
 
     if (!can_show_security_context_column ())
-        gsm_tree_view_add_excluded_column (GSM_TREE_VIEW (proctree), COL_SECURITYCONTEXT);
+        gsm_tree_view_add_excluded_column (proctree, COL_SECURITYCONTEXT);
 
-    gsm_tree_view_load_state (GSM_TREE_VIEW (proctree));
+    gsm_tree_view_load_state (proctree);
 
     GtkIconTheme* theme = gtk_icon_theme_get_default();
     g_signal_connect(G_OBJECT (theme), "changed", G_CALLBACK (cb_refresh_icons), app);
@@ -604,13 +594,15 @@ proctable_new (GsmApplication * const app)
     g_signal_connect (G_OBJECT (model_sort), "sort-column-changed",
                       G_CALLBACK (cb_save_tree_state), app);
 
-    g_signal_connect (app->settings, "changed::" GSM_SETTING_SHOW_DEPENDENCIES,
-                      G_CALLBACK (cb_show_dependencies_changed), app);
+    app->settings->signal_changed(GSM_SETTING_SHOW_DEPENDENCIES).connect([app](const Glib::ustring& key) {
+        cb_show_dependencies_changed(*app->settings.operator->(), key, app);
+    });
 
-    g_signal_connect (app->settings, "changed::" GSM_SETTING_SHOW_WHOSE_PROCESSES,
-                      G_CALLBACK (cb_show_whose_processes_changed), app);
+    app->settings->signal_changed(GSM_SETTING_SHOW_WHOSE_PROCESSES).connect([app](const Glib::ustring& key) {
+        cb_show_whose_processes_changed(*app->settings.operator->(), key, app);
+    });
 
-    gtk_widget_show (proctree);
+    gtk_widget_show (GTK_WIDGET (proctree));
 
     return proctree;
 }
@@ -657,9 +649,8 @@ get_process_name (ProcInfo *info,
 std::string
 ProcInfo::lookup_user(guint uid)
 {
-    typedef std::pair<ProcInfo::UserMap::iterator, bool> Pair;
-    ProcInfo::UserMap::value_type hint(uid, "");
-    Pair p(ProcInfo::users.insert(hint));
+    static std::map<guint, std::string> users;
+    auto p = users.insert({uid, ""});
 
     // procman_debug("User lookup for uid %u: %s", uid, (p.second ? "MISS" : "HIT"));
 
@@ -791,7 +782,7 @@ insert_info_to_tree (ProcInfo *info, GsmApplication *app, bool forced = false)
     filtered = gtk_tree_model_sort_get_model(GTK_TREE_MODEL_SORT(sorted));
     model = gtk_tree_model_filter_get_model (GTK_TREE_MODEL_FILTER (filtered));
     
-    if (g_settings_get_boolean (app->settings, GSM_SETTING_SHOW_DEPENDENCIES)) {
+    if (app->settings->get_boolean (GSM_SETTING_SHOW_DEPENDENCIES)) {
 
         ProcInfo *parent = 0;
 
@@ -920,7 +911,7 @@ update_info (GsmApplication *app, ProcInfo *info)
     g_assert(info->ppid != -1 || info->pid == 0);
 
     /* get cgroup data */
-    get_process_cgroup_info(info);
+    get_process_cgroup_info(*info);
 
     procman::get_process_systemd_info(info);
 }
@@ -970,7 +961,7 @@ ProcInfo::ProcInfo(pid_t pid)
 
     get_process_selinux_context (info);
     info->cgroup_name = NULL;
-    get_process_cgroup_info(info);
+    get_process_cgroup_info(*info);
 
     info->unit = info->session = info->seat = NULL;
     get_process_systemd_info(info);
@@ -1029,7 +1020,7 @@ refresh_list (GsmApplication *app, const pid_t* pid_list, const guint n)
     // pid_list == ProcInfo::all + addition
 
 
-    if (g_settings_get_boolean (app->settings, GSM_SETTING_SHOW_DEPENDENCIES)) {
+    if (app->settings->get_boolean (GSM_SETTING_SHOW_DEPENDENCIES)) {
 
         // insert process in the tree. walk through the addition list
         // (new process + process that have a new parent). This loop
@@ -1107,18 +1098,17 @@ proctable_update (GsmApplication *app)
     glibtop_cpu cpu;
     int which = 0;
     int arg = 0;
-    char *whose_processes = g_settings_get_string (app->settings, GSM_SETTING_SHOW_WHOSE_PROCESSES);
-    if (strcmp (whose_processes, "all") == 0) {
+    auto whose_processes = app->settings->get_string(GSM_SETTING_SHOW_WHOSE_PROCESSES);
+    if (whose_processes == "all") {
         which = GLIBTOP_KERN_PROC_ALL;
         arg = 0;
-    } else if (strcmp (whose_processes, "active") == 0) {
+    } else if (whose_processes == "active") {
         which = GLIBTOP_KERN_PROC_ALL | GLIBTOP_EXCLUDE_IDLE;
         arg = 0;
-    } else if (strcmp (whose_processes, "user") == 0) {
+    } else if (whose_processes == "user") {
       which = GLIBTOP_KERN_PROC_UID;
       arg = getuid ();
     }
-    g_free (whose_processes);
 
     pid_list = glibtop_get_proclist (&proclist, which, arg);
 
